# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin
from . import models


class BankInline(admin.StackedInline):
    model = models.Bank
    extra = 0
    fieldsets = (
        (_('general information'), {
            'fields': (
                ('int_code', 'cin',),
                ('abi', 'cab',), 'cc', 'note',
            )
        }),
        (_('visualization admin'), {
            'fields': ('status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'status', 'int_code', 'cin', 'abi', 'cab', 'cc',
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


class BankAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('abi', 'cab',)
    advanced_search_fields = ()
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': (
                'organization', ('abi', 'cab',),
                ('int_code', 'cin',), 'cc',
            )
        }),
        (_('note'), {
            'fields': ('note',),
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = (
        'id', 'status', 'organization',
        'abi', 'cab', 'int_code', 'cin', 'cc', 'ordering'
    )
    list_display_links = ('organization', 'abi', 'cab',)
    readonly_fields = (
        'creator', 'date_create', 'last_modifier', 'date_last_modify',
    )
    autocomplete_fields = ('organization',)


class BankDetailAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ()
    advanced_search_fields = ()
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': (
                ('abi', 'cab',),
                ('name', 'agency',),
                'address', 'zip_code', 'locality', 'province', 'country',
            )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = (
        'id', 'status', 'abi', 'cab', 'name', 'agency',
        'zip_code', 'locality', 'province', 'ordering'
    )
    list_display_links = ('name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


admin.site.register(models.Bank, BankAdmin)
admin.site.register(models.BankDetail, BankDetailAdmin)
