# -*- coding: utf-8 -*-

from rest_framework import serializers

from ... import models
from apps.role.core.serializers import ThuxRoleSerializerMixin
from thx.api.serializers import ThuxCreateSerializerMixin, ThuxUpdateSerializerMixin


# BANK
class BankSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_bank_bank'
        model = models.Bank
        fields = '__all__'


class BankCreateSerializer(
    ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return BankSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_bank_bank_create'
        model = models.Bank
        fields = '__all__'


class BankUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return BankSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_bank_bank_update'
        model = models.Bank
        fields = '__all__'


class BankEnableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_bank_bank_enable'
        model = models.Bank
        fields = '__all__'

    def to_representation(self, instance):
        return BankSerializer(instance, context=self.context).data


class BankDisableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_bank_bank_disable'
        model = models.Bank
        fields = '__all__'

    def to_representation(self, instance):
        return BankSerializer(instance, context=self.context).data


# BANK DETAIL
class BankDetailSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_bank_bank_detail'
        model = models.BankDetail
        fields = '__all__'


class BankDetailCreateSerializer(
    ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return BankDetailSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_bank_bank_detail_create'
        model = models.BankDetail
        fields = '__all__'


class BankDetailUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return BankDetailSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_bank_bank_detail_update'
        model = models.BankDetail
        fields = '__all__'


class BankDetailEnableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_bank_bank_detail_enable'
        model = models.BankDetail
        fields = '__all__'

    def to_representation(self, instance):
        return BankDetailSerializer(instance, context=self.context).data


class BankDetailDisableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_bank_bank_detail_disable'
        model = models.BankDetail
        fields = '__all__'

    def to_representation(self, instance):
        return BankDetailSerializer(instance, context=self.context).data
